	as top PPT maker, how would them make a reporting ppt to give feedback. make a ppt as top ppt maker
	
	• 工作流Dify的坑 - slide 1
		○ 每个节点被分装后基础功能的使用简单明了，但是有几个明显短板
			§ 当Agent处理未达预期后的调试诊断，特别复杂，且不直观。这部分耗时++
			§ AI不能高效接管，Dify并非能让AI码代码，需要人拖拉拽（工作流通病）不是面向未来的技术。这部分耗时+++（功能越复杂边际成本越高）
			§ Dify的学习成本在面对高阶用法时，需要查找各类文档，即使向AI提问也并不直观，还不一定有效。这部分耗时++
		
比如：拿我们的例子70%时间都在后期调优Agent输出结果稳定性。

	• MCP服务端创建 - slide 2
		○ 对接目标应用API
			§ 如果三方团队基于接口文档和业务文档学习API含义，字段含义。这部分耗时+++（第三方团队及原实施团队都产生耗时）
			§ 如果原团队能基于需求梳理接口文档，业务逻辑。这部分耗时+。
		○ MCP服务器创建并对接API
			§ 基于API文档及相关业务逻辑文档，AI可自动生成，这部分耗时，基本为0。
			
比如：拿我们的例子，Fred花了2天的时间在书里业务逻辑，接口，但实际MCP创建1小时。

	• 前端开发 - slide 3 - part 1
		○ 代码实现，基本上没啥成本如果我们对实现方法，代码结构有太高要求。这部分耗时+。
		○ 确认设计稿，简单设计，基本没啥成本，复杂功能，需要更平凡的沟通。这部分耗时+。
		○ 如果是精细化设计稿To C，这部分耗时++。
	• 需求等待 - slide 3 - part 2
		○ 开发的确简单很多，更多是等待需求输入，确认设计稿，并验收调优。
		
比如：Mark和Fred基本在接到需求后的2-3天完成。且还不是最有开发模式，也因为我们的demo没那么复杂。
